@@ -25,6 +25,7 @@
 #include "qgsmaplayermodel.h"
 #include "qgsmaptoolprofilecurve.h"
 #include "qgsmaptoolprofilecurvefromfeature.h"
+#include "qgsprofilerenderer.h"
 #include "qgsprojectelevationproperties.h"
 #include "qgsvectorlayerelevationproperties.h"
 #include "qgsrubberband.h"
@@ -59,6 +60,8 @@
 #include "qgsterrainprovider.h"
 #include "qgsprofilesourceregistry.h"
 #include "qgsnewnamedialog.h"
+#include "qgssymbolselectordialog.h"
+#include "qgsstyle.h"
 
 #include <QToolBar>
 #include <QProgressBar>
@@ -74,6 +77,7 @@ const QgsSettingsEntryBool *QgsElevationProfileWidget::settingShowLayerTree = ne
 const QgsSettingsEntryBool *QgsElevationProfileWidget::settingLockAxis = new QgsSettingsEntryBool( QStringLiteral( "lock-axis-ratio" ), QgsSettingsTree::sTreeElevationProfile, false, QStringLiteral( "Whether the the distance and elevation axis scales are locked to each other" ) );
 const QgsSettingsEntryString *QgsElevationProfileWidget::settingLastExportDir = new QgsSettingsEntryString( QStringLiteral( "last-export-dir" ), QgsSettingsTree::sTreeElevationProfile, QString(), QStringLiteral( "Last elevation profile export directory" ) );
 const QgsSettingsEntryColor *QgsElevationProfileWidget::settingBackgroundColor = new QgsSettingsEntryColor( QStringLiteral( "background-color" ), QgsSettingsTree::sTreeElevationProfile, QColor(), QStringLiteral( "Elevation profile chart background color" ) );
+const QgsSettingsEntryBool *QgsElevationProfileWidget::settingShowSubsections = new QgsSettingsEntryBool( QStringLiteral( "show-sub-sections" ), QgsSettingsTree::sTreeElevationProfile, false, QStringLiteral( "Whether to display subsections" ) );
 //
 // QgsElevationProfileLayersDialog
 //
@@ -411,6 +415,23 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
 
   mOptionsMenu->addSeparator();
 
+  // show Subsections Indicator Action
+  // create a default simple symbology
+  mSubsectionsSymbol = QgsProfilePlotRenderer::defaultSubSectionsSymbol();
+  mShowSubsectionsAction = new QAction( tr( "Show Subsections Indicator" ), this );
+  mShowSubsectionsAction->setCheckable( true );
+  mShowSubsectionsAction->setChecked( settingShowSubsections->value() );
+  connect( mShowSubsectionsAction, &QAction::triggered, this, &QgsElevationProfileWidget::showSubsectionsTriggered );
+  mOptionsMenu->addAction( mShowSubsectionsAction );
+
+  // Edit Subsections Symbology action
+  mSubsectionsSymbologyAction = new QAction( tr( "Subsections Symbology…" ), this );
+  mSubsectionsSymbologyAction->setEnabled( settingShowSubsections->value() );
+  connect( mSubsectionsSymbologyAction, &QAction::triggered, this, &QgsElevationProfileWidget::editSubsectionsSymbology );
+  mOptionsMenu->addAction( mSubsectionsSymbologyAction );
+
+  mOptionsMenu->addSeparator();
+
   mRenameProfileAction = new QAction( tr( "Rename Profile…" ), this );
   connect( mRenameProfileAction, &QAction::triggered, this, &QgsElevationProfileWidget::renameProfileTriggered );
   mOptionsMenu->addAction( mRenameProfileAction );
@@ -457,7 +478,8 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   } );
   setLayout( layout );
 
-  mDockableWidgetHelper = new QgsDockableWidgetHelper( true, mCanvasName, this, QgisApp::instance(), Qt::BottomDockWidgetArea, QStringList(), true );
+  mDockableWidgetHelper = new QgsDockableWidgetHelper( mCanvasName, this, QgisApp::instance(), mCanvasName, QStringList(), QgsDockableWidgetHelper::OpeningMode::RespectSetting, true, Qt::DockWidgetArea::BottomDockWidgetArea, QgsDockableWidgetHelper::Option::RaiseTab );
+
   QToolButton *toggleButton = mDockableWidgetHelper->createDockUndockToolButton();
   toggleButton->setToolTip( tr( "Dock Elevation Profile View" ) );
   toolBar->addWidget( toggleButton );
@@ -655,6 +677,7 @@ void QgsElevationProfileWidget::setProfileCurve( const QgsGeometry &curve, bool
 {
   mNudgeLeftAction->setEnabled( !curve.isEmpty() );
   mNudgeRightAction->setEnabled( !curve.isEmpty() );
+  mShowSubsectionsAction->setEnabled( !curve.isEmpty() );
 
   mProfileCurve = curve;
   createOrUpdateRubberBands();
@@ -690,6 +713,7 @@ void QgsElevationProfileWidget::updatePlot()
 {
   mCanvas->setTolerance( mSettingsAction->toleranceSpinBox()->value() );
   mCanvas->setCrs( QgsProject::instance()->crs3D() );
+  showSubsectionsTriggered();
 
   if ( !mProfileCurve.isEmpty() )
   {
@@ -730,6 +754,7 @@ void QgsElevationProfileWidget::clear()
   }
   mNudgeLeftAction->setEnabled( false );
   mNudgeRightAction->setEnabled( false );
+  mShowSubsectionsAction->setEnabled( false );
   mProfileCurve = QgsGeometry();
 }
 
@@ -781,7 +806,7 @@ void QgsElevationProfileWidget::exportAsPdf()
 
   QgsRenderContext rc = QgsRenderContext::fromQPainter( &p );
   rc.setFlag( Qgis::RenderContextFlag::Antialiasing, true );
-  rc.setFlag( Qgis::RenderContextFlag::ForceVectorOutput, true );
+  rc.setRasterizedRenderingPolicy( Qgis::RasterizedRenderingPolicy::PreferVector );
   rc.setFlag( Qgis::RenderContextFlag::ApplyScalingWorkaroundForTextRendering, true );
   rc.setFlag( Qgis::RenderContextFlag::HighQualityImageTransforms, true );
   rc.setTextRenderFormat( Qgis::TextRenderFormat::AlwaysText );
@@ -896,7 +921,7 @@ void QgsElevationProfileWidget::exportResults( Qgis::ProfileExportType type )
   sources << registrySources;
   for ( QgsMapLayer *layer : layersToGenerate )
   {
-    if ( QgsAbstractProfileSource *source = dynamic_cast<QgsAbstractProfileSource *>( layer ) )
+    if ( QgsAbstractProfileSource *source = layer->profileSource() )
       sources.append( source );
   }
 
@@ -971,6 +996,33 @@ void QgsElevationProfileWidget::renameProfileTriggered()
   }
 }
 
+void QgsElevationProfileWidget::showSubsectionsTriggered()
+{
+  const bool showSubSections = mShowSubsectionsAction->isChecked();
+
+  settingShowSubsections->setValue( showSubSections );
+  mSubsectionsSymbologyAction->setEnabled( showSubSections );
+
+  if ( showSubSections )
+  {
+    mCanvas->setSubsectionsSymbol( mSubsectionsSymbol ? mSubsectionsSymbol->clone() : nullptr );
+  }
+  else
+  {
+    mCanvas->setSubsectionsSymbol( nullptr );
+  }
+}
+
+void QgsElevationProfileWidget::editSubsectionsSymbology()
+{
+  QgsSymbolSelectorDialog symbolDialog( mSubsectionsSymbol.get(), QgsStyle::defaultStyle(), nullptr, this );
+  symbolDialog.setWindowTitle( tr( "Subsections Symbol Selector" ) );
+  if ( symbolDialog.exec() )
+  {
+    showSubsectionsTriggered();
+  }
+}
+
 void QgsElevationProfileWidget::createOrUpdateRubberBands()
 {
   if ( !mRubberBand )
