@@ -184,7 +184,7 @@ void QgsCreateLineItemMapTool::lineCaptured( const QgsCurve *line )
   std::unique_ptr<QgsAbstractGeometry> geometry( line->simplifiedTypeRef()->clone() );
   if ( qgsgeometry_cast<QgsCurve *>( geometry.get() ) )
   {
-    auto createdItem = std::make_unique<QgsAnnotationLineItem>( qgsgeometry_cast<QgsCurve *>( geometry.release() ) );
+    auto createdItem = std::make_unique<QgsAnnotationLineItem>( qgis::down_cast<QgsCurve *>( geometry.release() ) );
 
     std::unique_ptr<QgsLineSymbol> lineSymbol = QgsApplication::recentStyleHandler()->recentSymbol<QgsLineSymbol>( QStringLiteral( "line_annotation_item" ) );
     if ( !lineSymbol )
