@@ -406,6 +406,27 @@ void QgsDiagramProperties::insertDefaults()
   mDiagramTypeComboBox_currentIndexChanged( mDiagramTypeComboBox->currentIndex() );
 }
 
+void QgsDiagramProperties::updateDataDefinedButtons()
+{
+  const QList<QgsPropertyOverrideButton *> propertyOverrideButtons { findChildren<QgsPropertyOverrideButton *>() };
+  for ( QgsPropertyOverrideButton *button : propertyOverrideButtons )
+  {
+    updateDataDefinedButton( button );
+  }
+}
+
+void QgsDiagramProperties::updateDataDefinedButton( QgsPropertyOverrideButton *button )
+{
+  if ( !button )
+    return;
+
+  if ( button->propertyKey() < 0 )
+    return;
+
+  const QgsWidgetWrapper::Property key = static_cast<QgsWidgetWrapper::Property>( button->propertyKey() );
+  whileBlocking( button )->setToProperty( mDataDefinedProperties.property( key ) );
+}
+
 void QgsDiagramProperties::syncToLayer()
 {
   const QgsDiagramRenderer *renderer = mLayer->diagramRenderer();
@@ -620,6 +641,7 @@ void QgsDiagramProperties::syncToSettings( const QgsDiagramLayerSettings *dls )
     mShowAllCheckBox->setChecked( dls->showAllDiagrams() );
 
     mDataDefinedProperties = dls->dataDefinedProperties();
+    updateDataDefinedButtons();
   }
 }
 
@@ -927,6 +949,13 @@ std::unique_ptr<QgsDiagramSettings> QgsDiagramProperties::createDiagramSettings(
   ds->diagramOrientation = static_cast<QgsDiagramSettings::DiagramOrientation>( mOrientationButtonGroup->checkedButton()->property( "direction" ).toInt() );
 
   ds->barWidth = mBarWidthSpinBox->value();
+  if ( mDiagramType == QgsStackedBarDiagram::DIAGRAM_NAME_STACKED_BAR )
+  {
+    if ( ds->diagramOrientation == QgsDiagramSettings::DiagramOrientation::Up || ds->diagramOrientation == QgsDiagramSettings::DiagramOrientation::Down )
+      ds->size.setWidth( ds->barWidth );
+    else
+      ds->size.setHeight( ds->barWidth );
+  }
 
   ds->setAxisLineSymbol( mAxisLineStyleButton->clonedSymbol<QgsLineSymbol>() );
   ds->setShowAxis( mShowAxisGroupBox->isChecked() );
