@@ -23,6 +23,7 @@
 #include "qgsapplication.h"
 #include "qgsfeedback.h"
 #include "qgsvectorlayer.h"
+#include "qgsmessagelog.h"
 
 #include <QSqlRecord>
 #include <QSqlField>
@@ -55,7 +56,7 @@ class QgsOracleQuery : public QSqlQuery
   public:
     explicit QgsOracleQuery( std::shared_ptr<QgsPoolOracleConn> pconn )
       : QSqlQuery( *pconn->get() )
-      , mPconn( pconn )
+      , mPconn( std::move( pconn ) )
     {}
 
   private:
@@ -289,6 +290,16 @@ QgsVectorLayer *QgsOracleProviderConnection::createSqlVectorLayer( const QgsAbst
   return vl.release();
 }
 
+Qgis::DatabaseProviderTableImportCapabilities QgsOracleProviderConnection::tableImportCapabilities() const
+{
+  return Qgis::DatabaseProviderTableImportCapability::SetGeometryColumnName | Qgis::DatabaseProviderTableImportCapability::SetPrimaryKeyName;
+}
+
+QString QgsOracleProviderConnection::defaultPrimaryKeyColumnName() const
+{
+  return QStringLiteral( "id" );
+}
+
 void QgsOracleProviderConnection::store( const QString &name ) const
 {
   QString baseKey = QStringLiteral( "/Oracle/connections/" );
@@ -315,6 +326,10 @@ void QgsOracleProviderConnection::store( const QString &name ) const
     {
       settings.setValue( param, dsUri.param( param ) );
     }
+    else
+    {
+      settings.remove( param );
+    }
   }
 
   // From configuration
@@ -324,6 +339,10 @@ void QgsOracleProviderConnection::store( const QString &name ) const
     {
       settings.setValue( p, configuration().value( p ) );
     }
+    else
+    {
+      settings.remove( p );
+    }
   }
   settings.endGroup();
   settings.endGroup();
@@ -349,6 +368,11 @@ QList<QgsVectorDataProvider::NativeType> QgsOracleProviderConnection::nativeType
   return types;
 }
 
+QString QgsOracleProviderConnection::defaultGeometryColumnName() const
+{
+  return QStringLiteral( "GEOM" );
+}
+
 QMultiMap<Qgis::SqlKeywordCategory, QStringList> QgsOracleProviderConnection::sqlDictionary()
 {
   return {
@@ -1451,6 +1475,7 @@ void QgsOracleProviderConnection::createVectorTable( const QString &schema, cons
   }
   QMap<int, int> map;
   QString errCause;
+  QString createdLayerUri;
   const Qgis::VectorExportResult res = QgsOracleProvider::createEmptyLayer(
     newUri.uri(),
     fields,
@@ -1458,6 +1483,7 @@ void QgsOracleProviderConnection::createVectorTable( const QString &schema, cons
     srs,
     overwrite,
     map,
+    createdLayerUri,
     errCause,
     options
   );
@@ -1465,6 +1491,26 @@ void QgsOracleProviderConnection::createVectorTable( const QString &schema, cons
     throw QgsProviderConnectionException( QObject::tr( "An error occurred while creating the vector layer: %1" ).arg( errCause ) );
 }
 
+QString QgsOracleProviderConnection::createVectorLayerExporterDestinationUri( const VectorLayerExporterOptions &options, QVariantMap &providerOptions ) const
+{
+  QgsDataSourceUri destUri( uri() );
+
+  destUri.setTable( options.layerName );
+  destUri.setSchema( options.schema );
+  destUri.setGeometryColumn( options.wkbType != Qgis::WkbType::NoGeometry ? ( options.geometryColumn.isEmpty() ? QStringLiteral( "GEOM" ) : options.geometryColumn ) : QString() );
+  if ( !options.primaryKeyColumns.isEmpty() )
+  {
+    if ( options.primaryKeyColumns.length() > 1 )
+    {
+      QgsMessageLog::logMessage( QStringLiteral( "Multiple primary keys are not supported by Oracle, ignoring" ), QString(), Qgis::MessageLevel::Info );
+    }
+    destUri.setKeyColumn( options.primaryKeyColumns.at( 0 ) );
+  }
+
+  providerOptions.clear();
+  return destUri.uri( false );
+}
+
 QString QgsOracleProviderConnection::tableUri( const QString &schema, const QString &name ) const
 {
   const auto tableInfo { table( schema, name ) };
